pub struct HashHasher { /* private fields */ }Available on crate feature
rand and neither target_os=solana nor BPF only.Expand description
A faster, but less collision resistant hasher for hashes.
Specialized hasher that uses a random 8 bytes subslice of the hash as the hash value. Should not be used when collisions might be used to mount DOS attacks.
Using this results in about 4x faster lookups in a typical hashmap.