HashHasherBuilder

Struct HashHasherBuilder 

pub struct HashHasherBuilder { /* private fields */ }
Available on crate feature rand and neither target_os=solana nor BPF only.
A builder for faster, but less collision resistant hasher for hashes.

Initializes HashHasher instances that use an 8-byte slice of the hash as the hash value. Should not be used when collisions might be used to mount DOS attacks.

Using this results in about 4x faster lookups in a typical hashmap.

Implementations

Source

impl HashHasherBuilder

pub fn with_offset(offset: usize) -> Self

Constructs a builder with a specific offset.

Prefer HashHasherBuilder::default() unless deterministic results are required.

pub fn offset(&self) -> usize

Returns the offset used to construct this builder.